@@ -186,13 +186,9 @@ click_help_cb (GtkWidget * widget,
 	GtkWidget * window = data;
 	GError * error = NULL;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
 	gtk_show_uri_on_window (GTK_WINDOW (window), "help:mate-search-tool",  
 	                        gtk_get_current_event_time (), &error);
-#else
-	gtk_show_uri (gtk_widget_get_screen (widget), "help:mate-search-tool",  
-	              gtk_get_current_event_time (), &error);
-#endif
+
 	if (error) {
 		GtkWidget * dialog;
 
