@@ -130,13 +130,8 @@ set_window_default_size (GdictApplet *applet)
   GtkWidget *widget, *defbox;
   gint width, height;
   gint font_size;
-#if GTK_CHECK_VERSION (3, 22, 0)
   GdkDisplay *display;
   GdkMonitor *monitor_num;
-#else
-  GdkScreen *screen;
-  gint monitor_num;
-#endif
   GtkRequisition req;
   GdkRectangle monitor;
 
@@ -159,18 +154,10 @@ set_window_default_size (GdictApplet *applet)
   height = MAX (height, req.height);
 
   /* ... but make it no larger than half the monitor size */
-#if GTK_CHECK_VERSION (3, 22, 0)
   display = gtk_widget_get_display (widget);
   monitor_num = gdk_display_get_monitor_at_window (display,
                                                    gtk_widget_get_window (widget));
   gdk_monitor_get_geometry (monitor_num, &monitor);
-#else
-  screen = gtk_widget_get_screen (widget);
-  monitor_num = gdk_screen_get_monitor_at_window (screen,
-                                                  gtk_widget_get_window (widget));
-
-  gdk_screen_get_monitor_geometry (screen, monitor_num, &monitor);
-#endif
 
   width = MIN (width, monitor.width / 2);
   height = MIN (height, monitor.height / 2);
@@ -729,11 +716,7 @@ gdict_applet_cmd_help (GtkAction *action,
 {
   GError *err = NULL;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
   gtk_show_uri_on_window (NULL,
-#else
-  gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (applet)),
-#endif
 		"help:mate-dictionary/mate-dictionary-applet",
 		gtk_get_current_event_time (), &err);
   
