@@ -160,23 +160,14 @@ GdkWindow *
 screenshot_find_current_window ()
 {
   GdkWindow *current_window;
-#if GTK_CHECK_VERSION (3, 20, 0)
   GdkDisplay *display;
   GdkSeat *seat;
-#else
-  GdkDeviceManager *manager;
-#endif
   GdkDevice *device;
 
   current_window = screenshot_find_active_window ();
-#if GTK_CHECK_VERSION (3, 20, 0)
   display = gdk_window_get_display (current_window);
   seat = gdk_display_get_default_seat (display);
   device = gdk_seat_get_pointer (seat);
-#else
-  manager = gdk_display_get_device_manager (gdk_display_get_default ());
-  device = gdk_device_manager_get_client_pointer (manager);
-#endif
 
   /* If there's no active window, we fall back to returning the
    * window that the cursor is in.
@@ -389,12 +380,7 @@ screenshot_select_area_async (SelectAreaCallback callback)
 {
   GdkDisplay *display;
   GdkCursor               *cursor;
-#if GTK_CHECK_VERSION (3, 20, 0)
   GdkSeat *seat;
-#else
-  GdkDeviceManager *manager;
-  GdkDevice *pointer, *keyboard;
-#endif
   GdkGrabStatus res;
   select_area_filter_data  data;
   GdkRectangle *rectangle;
@@ -418,7 +404,6 @@ screenshot_select_area_async (SelectAreaCallback callback)
   display = gdk_display_get_default ();
   cursor = gdk_cursor_new_for_display (display, GDK_CROSSHAIR);
 
-#if GTK_CHECK_VERSION (3, 20, 0)
   seat = gdk_display_get_default_seat (display);
 
   res = gdk_seat_grab (seat,
@@ -439,41 +424,6 @@ screenshot_select_area_async (SelectAreaCallback callback)
   gtk_main ();
 
   gdk_seat_ungrab (seat);
-#else
-  manager = gdk_display_get_device_manager (display);
-  pointer = gdk_device_manager_get_client_pointer (manager);
-  keyboard = gdk_device_get_associated_device (pointer);
-
-  res = gdk_device_grab (pointer, gtk_widget_get_window (data.window),
-                         GDK_OWNERSHIP_NONE, FALSE,
-                         GDK_POINTER_MOTION_MASK |
-                         GDK_BUTTON_PRESS_MASK | 
-                         GDK_BUTTON_RELEASE_MASK,
-                         cursor, GDK_CURRENT_TIME);
-
-  if (res != GDK_GRAB_SUCCESS)
-    {
-      g_object_unref (cursor);
-      goto out;
-    }
-
-  res = gdk_device_grab (keyboard, gtk_widget_get_window (data.window),
-                         GDK_OWNERSHIP_NONE, FALSE,
-                         GDK_KEY_PRESS_MASK |
-                         GDK_KEY_RELEASE_MASK,
-                         NULL, GDK_CURRENT_TIME);
-  if (res != GDK_GRAB_SUCCESS)
-    {
-      gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-      g_object_unref (cursor);
-      goto out;
-    }
-
-  gtk_main ();
-
-  gdk_device_ungrab (keyboard, GDK_CURRENT_TIME);
-  gdk_device_ungrab (pointer, GDK_CURRENT_TIME);
-#endif
 
   gtk_widget_destroy (data.window);
   g_object_unref (cursor);
@@ -515,19 +465,13 @@ find_wm_window (Window xid)
 static cairo_region_t *
 make_region_with_monitors (GdkScreen *screen)
 {
-#if GTK_CHECK_VERSION (3, 22, 0)
   GdkDisplay     *display;
-#endif
   cairo_region_t *region;
   int num_monitors;
   int i;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
   display = gdk_screen_get_display (screen);
   num_monitors = gdk_display_get_n_monitors (display);
-#else
-  num_monitors = gdk_screen_get_n_monitors (screen);
-#endif
 
   region = cairo_region_create ();
 
@@ -535,11 +479,7 @@ make_region_with_monitors (GdkScreen *screen)
     {
       GdkRectangle rect;
 
-#if GTK_CHECK_VERSION (3, 22, 0)
       gdk_monitor_get_geometry (gdk_display_get_monitor (display, i), &rect);
-#else
-      gdk_screen_get_monitor_geometry (screen, i, &rect);
-#endif
       cairo_region_union_rectangle (region, &rect);
     }
 
@@ -628,15 +568,17 @@ mask_monitors (GdkPixbuf *pixbuf, GdkWindow *root_window)
   cairo_region_t *region_with_monitors;
   cairo_region_t *invisible_region;
   cairo_rectangle_int_t rect;
+  gint scale;
 
   screen = gdk_window_get_screen (root_window);
+  scale = gdk_window_get_scale_factor (root_window);
 
   region_with_monitors = make_region_with_monitors (screen);
 
   rect.x = 0;
   rect.y = 0;
-  rect.width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen));
-  rect.height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen));
+  rect.width = WidthOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
+  rect.height = HeightOfScreen (gdk_x11_screen_get_xscreen (screen)) / scale;
 
   invisible_region = cairo_region_create_rectangle (&rect);
   cairo_region_subtract (invisible_region, region_with_monitors);
@@ -658,6 +600,7 @@ screenshot_get_pixbuf (GdkWindow    *window,
   GdkPixbuf *screenshot;
   gint x_real_orig, y_real_orig, x_orig, y_orig;
   gint width, real_width, height, real_height;
+  gint screen_width, screen_height, scale;
 
   /* If the screenshot should include the border, we look for the WM window. */
 
@@ -675,9 +618,13 @@ screenshot_get_pixbuf (GdkWindow    *window,
     }
 
   root = gdk_get_default_root_window ();
+  scale = gdk_window_get_scale_factor (root);
 
-		real_width = gdk_window_get_width(window);
-		real_height = gdk_window_get_height(window);
+  real_width = gdk_window_get_width (window);
+  real_height = gdk_window_get_height (window);
+
+  screen_width = WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) / scale;
+  screen_height = HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) / scale;
 
   gdk_window_get_origin (window, &x_real_orig, &y_real_orig);
 
@@ -698,11 +645,11 @@ screenshot_get_pixbuf (GdkWindow    *window,
       y_orig = 0;
     }
 
-  if (x_orig + width > WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
-    width = WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - x_orig;
+  if (x_orig + width > screen_width)
+    width = screen_width - x_orig;
 
-  if (y_orig + height > HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
-    height = HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - y_orig;
+  if (y_orig + height > screen_height)
+    height = screen_height - y_orig;
 
   if (rectangle)
     {
@@ -742,6 +689,12 @@ screenshot_get_pixbuf (GdkWindow    *window,
         {
           gboolean has_alpha = gdk_pixbuf_get_has_alpha (screenshot);
 
+          if (scale)
+            {
+              width *= scale;
+              height *= scale;
+            }
+
           tmp = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, width, height);
           gdk_pixbuf_fill (tmp, 0);
 
@@ -753,8 +706,8 @@ screenshot_get_pixbuf (GdkWindow    *window,
 
               rec_x = rectangles[i].x;
               rec_y = rectangles[i].y;
-              rec_width = rectangles[i].width;
-              rec_height = rectangles[i].height;
+              rec_width = rectangles[i].width / scale;
+              rec_height = rectangles[i].height / scale;
 
               if (x_real_orig < 0)
                 {
@@ -770,11 +723,17 @@ screenshot_get_pixbuf (GdkWindow    *window,
                   rec_height += y_real_orig;
                 }
 
-              if (x_orig + rec_x + rec_width > WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
-                rec_width = WidthOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - x_orig - rec_x;
+              if (x_orig + rec_x + rec_width > screen_width)
+                rec_width = screen_width - x_orig - rec_x;
 
-              if (y_orig + rec_y + rec_height > HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())))
-                rec_height = HeightOfScreen (gdk_x11_screen_get_xscreen (gdk_screen_get_default ())) - y_orig - rec_y;
+              if (y_orig + rec_y + rec_height > screen_height)
+                rec_height = screen_height - y_orig - rec_y;
+
+              if (scale)
+                {
+                  rec_width *= scale;
+                  rec_height *= scale;
+                }
 
               for (y = rec_y; y < rec_y + rec_height; y++)
                 {
@@ -782,7 +741,7 @@ screenshot_get_pixbuf (GdkWindow    *window,
                   gint x;
 
                   src_pixels = gdk_pixbuf_get_pixels (screenshot)
-                             + y * gdk_pixbuf_get_rowstride(screenshot)
+                             + y * gdk_pixbuf_get_rowstride (screenshot)
                              + rec_x * (has_alpha ? 4 : 3);
                   dest_pixels = gdk_pixbuf_get_pixels (tmp)
                               + y * gdk_pixbuf_get_rowstride (tmp)
@@ -820,33 +779,31 @@ screenshot_get_pixbuf (GdkWindow    *window,
 
       if (cursor_pixbuf != NULL)
         {
-#if GTK_CHECK_VERSION (3, 20, 0)
           GdkDisplay *display;
           GdkSeat *seat;
-#else
-          GdkDeviceManager *manager;
-#endif
           GdkDevice *device;
           GdkRectangle r1, r2;
           gint cx, cy, xhot, yhot;
 
-#if GTK_CHECK_VERSION (3, 20, 0)
           display = gdk_window_get_display (window);
           seat = gdk_display_get_default_seat (display);
           device = gdk_seat_get_pointer (seat);
-#else
-          manager = gdk_display_get_device_manager (gdk_display_get_default ());
-          device = gdk_device_manager_get_client_pointer (manager);
-#endif
+
           gdk_window_get_device_position (window, device, &cx, &cy, NULL);
           sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "x_hot"), "%d", &xhot);
           sscanf (gdk_pixbuf_get_option (cursor_pixbuf, "y_hot"), "%d", &yhot);
 
+          if (scale)
+            {
+              cx *= scale;
+              cy *= scale;
+            }
+
           /* in r1 we have the window coordinates */
           r1.x = x_real_orig;
           r1.y = y_real_orig;
-          r1.width = real_width;
-          r1.height = real_height;
+          r1.width = real_width * scale;
+          r1.height = real_height * scale;
 
           /* in r2 we have the cursor window coordinates */
           r2.x = cx + x_real_orig;
